==> openscada-0.7.1.tar.lzma: openscada-0.7.1/src/moduls/ui/WebCfgD/VCAhtml.cpp <==
const char *WebCfgDVCA_html=
   "<?xml version='1.0' ?>\n"
   "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN'\n"
   "'DTD/xhtml1-transitional.dtd'>\n"
   "<html xmlns='http://www.w3.org/1999/xhtml'>\n"
   "<head>\n"
   "  <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'/>\n"
   "  <meta http-equiv='Cache-Control' content='no-store, no-cache, must-revalidate'/>\n"
   "  <meta http-equiv='Cache-Control' content='post-check=0, pre-check=0'/>\n"
   "  <meta http-equiv='Content-Script-Type' content='text/javascript'/>\n"
   "  <link rel='shortcut icon' href='/WebCfgD/ico' type='image' />\n"
   "  <title>###OpenSCADA. Dynamic WEB configurator###</title>\n"
   "\n"
   "  <style type='text/css'>\n"
   "    body { background-color:#818181; }\n"
   "    select { font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    #popupmenu { position: absolute; border: 0; width: 150px; height: 150px; overflow : auto; z-index: 10; }\n"
   "    #popupmenu select { background-color: #E6E6E6; border: 1px solid black; padding: 1px; }\n"
   "    #combomenu { position: absolute; border: 1px solid black; width: 150px; height: 120px; overflow: auto; background-color: white; padding: 1px; z-index: 10; }\n"
   "    #combomenu select { background-color: white; border: 0; }\n"
   "    table.main { background-color: #E6E6E6; border: 3px ridge #FF9253; padding: 5px; width: auto; table-layout: fixed; font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    table.main input,select { font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    table.main td.title { color : blue; font-family : Arial; font-size : 30px; font-style : italic; text-align : center; }\n"
   "    table.main td.tool { text-align: left; border-top: 2px solid black; }\n"
   "    table.main td.tool img { height: 22px; border: 0; vertical-align: middle; }\n"
   "    table.main td.status { text-align: left; }\n"
   "    table.main tr.body { background-color : lightgrey; overflow : auto; }\n"
   "    table.main td.tree { background-color : #F7FFF6; width: 250px; text-align: left; vertical-align : top; border: 3px ridge #F7FFF6; white-space: nowrap; color: black; }\n"
   "    table.main td.tree li.select { background-color : #BDEBED; }\n"
   "    table.main td.tree ul { background-color: #F7FFF6; background-repeat: repeat-y; background-attachment: scroll; background-position: left top; }\n"
   "    table.main td.tree div { overflow: auto; width: 250px; padding: 5px; max-height: 500px; }\n"
   "    table.main td.page { width: 600px; text-align: left; vertical-align : top; border: 3px outset #F7F7F1; background-color: #F7F7F1; }\n"
   "    table.page { width: 100%; padding: 2px; }\n"
   "    table.page td.title { color: black; font-family : Arial; font-size : 20px; font-style : italic; text-align : left; padding-bottom: 5px; }\n"
   "    table.page td.title img { vertical-align: middle; height: 32px; }\n"
   "    table.page td.tabs { }\n"
   "    table.page td.tabs span { padding-left: 5px; padding-right: 5px; padding-bottom: 2px; padding-top: 2px; border: 1px solid gray; white-space: nowrap; background-color: #DEDED9; cursor: pointer; }\n"
   "    table.page td.tabs span.active { background-color: #F7F7F1; cursor: default; border-bottom: 0px none; border-top: 2px solid green; }\n"
   "    table.page td.content { border : 2px ridge grey; text-align : left; vertical-align : top; height: 300px; padding: 5px; }\n"
   "    table.page td.content #pgCont { overflow: auto; width: 600px; max-height: 440px; }\n"
   "    table.page td.content div.elem { margin-bottom: 2px; overflow: visible; width: auto; }\n"
   "    table.page td.content div.elem span.label { white-space: nowrap; padding-right: 3px; }\n"
   "    table.page td.content div.elem span.const { font-weight: bold; }\n"
   "    table.page td.content div.elem textarea { width: 99%; }\n"
   "    table.page td.content fieldset.elem { margin : 0px; margin-bottom: 2px; padding: 3px; }\n"
   "    table.page td.content div.table { width: auto; border: 1px solid black; height: 200px; background-color: white; overflow: auto; padding: 2px; }\n"
   "    table.page td.content table.elem { border: 1px solid black; border-collapse: collapse; empty-cells: show; }\n"
   "    table.page td.content table.elem th { border: 1px solid black; background-color: #E6E6E6; text-align: center; white-space: nowrap; }\n"
   "    table.page td.content table.elem td { border: 1px solid black; white-space: nowrap; }\n"
   "    table.page td.content table.elem td.hd { background-color: #E6E6E6; font-weight: bold; text-align: center; }\n"
   "    table.page td.content table.elem td input,select { vertical-align: middle; border: 1px solid gray; }\n"
   "    table.page td.content table.elem td img { vertical-align: middle; height: 16px; cursor: pointer; }\n"
   "    table.page td.content table.elem tr.select td { background-color: #00C8FF; }\n"
   "    table.page td.content .list { width: 50%; }\n"
   "    table.page td.content .picture { border: 1px solid blue; vertical-align: top; }\n"
   "    table.page td.content div.elem .line { padding-right: 3px; }\n"
   "    table.page td.content div.elem .line input,select { vertical-align: middle; border: 1px solid black; }\n"
   "    table.page td.content div.elem .line img { vertical-align: middle; height: 18px; cursor: pointer; }\n"
   "    table.page td.content div.elem .number input { text-align: right; }\n"
   "    ul.tree { clear: both; list-style-image: none; list-style-position: outside; list-style-type: none; margin: 0px; padding: 0px; white-space: nowrap; }\n"
   "    ul.tree a { text-decoration:none; color: black; }\n"
   "    ul.tree a.pm { cursor: pointer; }\n"
   "    ul.tree img { vertical-align:middle; }\n"
   "    ul.tree ul { list-style-image: none; list-style-position: outside; list-style-type: none; margin: 0; padding: 0 0 0 17px; }\n"
   "    a.active img {  cursor: pointer; }\n"
   "    a.inactive img { cursor: default; }\n"
   "  </style>\n"
   "</head>\n"
   "<body alink='#33ccff' link='#3366ff' text='#000000' vlink='#339999'>\n"
   "<center>\n"
   "<table class='main' border='0' cellspacing='3px'>\n"
   " <tr><td class='title' colspan='2'>###OpenSCADA. Dynamic WEB configurator###</td></tr>\n"
   " <tr><td class='tool' colspan='2'>\n"
   "  <a id='actLoad' class='inactive' title='###Load###'><img src='/WebCfgD/img_load?filtr=gray&size=22' /></a>\n"
   "  <a id='actSave' class='inactive' title='###Save###'><img src='/WebCfgD/img_save?filtr=gray&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <a id='actUp' class='inactive' title='###Up###'><img src='/WebCfgD/img_up?filtr=gray&size=22' /></a>\n"
   "  <a id='actPrevious' class='inactive' title='###Previous###'><img src='/WebCfgD/img_previous?filtr=gray&size=22' /></a>\n"
   "  <a id='actNext' class='inactive' title='###Next###'><img src='/WebCfgD/img_next?filtr=gray&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line'/>\n"
   "  <a id='actAddIt' class='inactive' title='###Add item###'><img src='/WebCfgD/img_it_add?filtr=gray&size=22' /></a>\n"
   "  <a id='actDelIt' class='inactive' title='###Delete item###'><img src='/WebCfgD/img_it_del?filtr=gray&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line'/>\n"
   "  <a id='actCopy' class='inactive' title='###Copy item###'><img src='/WebCfgD/img_editcopy?filtr=gray&size=22' /></a>\n"
   "  <a id='actCut' class='inactive' title='###Cut item###'><img src='/WebCfgD/img_editcut?filtr=gray&size=22' /></a>\n"
   "  <a id='actPaste' class='inactive' title='###Paste item###'><img src='/WebCfgD/img_editpaste?filtr=gray&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <a id='actUpdate' class='active' title='###Reload item and tree###'><img src='/WebCfgD/img_reload?filtr=none&size=22' /></a>\n"
   "  <a id='actStart' class='active' title='###Start periodic update###'><img src='/WebCfgD/img_start?filtr=none&size=22' /></a>\n"
   "  <a id='actStop' class='inactive' title='###Stop periodic update###'><img src='/WebCfgD/img_stop?filtr=gray&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <a id='actAbout' class='active' href='/WebCfgD/about' title='###About###'><img src='/WebCfgD/img_help?size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <span id='selPath' />\n"
   " </td></tr>\n"
   " <tr class='body'>\n"
   "  <td class='tree'><div><ul id='treeRoot' class='tree' /></div></td>\n"
   "  <td class='page'>\n"
   "   <table class='page' border='0' cellspacing='0'>\n"
   "    <tr><td class='title'><img id='pgIco' alt='' /><span id='pgTitle' /></td></tr>\n"
   "    <tr><td id='pgTabs' class='tabs'></td></tr>\n"
   "    <tr><td class='content'><div id='pgCont'></div></td></tr>\n"
   "   </table>\n"
   "  </td>\n"
   " </tr>\n"
   " <tr><td id='status' class='status' colspan='2'/></tr>\n"
   "</table>\n"
   "</center>\n"
   "<script src='/WebCfgD/script.js' type='text/javascript'></script>\n"
   "</body>\n"
   "</html>\n";

==> openscada-0.7.2.tar.lzma: openscada-0.7.2/src/moduls/ui/WebCfgD/VCAhtml.cpp <==
const char *WebCfgDVCA_html=
   "<?xml version='1.0' ?>\n"
   "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN'\n"
   "'DTD/xhtml1-transitional.dtd'>\n"
   "<html xmlns='http://www.w3.org/1999/xhtml'>\n"
   "<head>\n"
   "  <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'/>\n"
   "  <meta http-equiv='Cache-Control' content='no-store, no-cache, must-revalidate'/>\n"
   "  <meta http-equiv='Cache-Control' content='post-check=0, pre-check=0'/>\n"
   "  <meta http-equiv='Content-Script-Type' content='text/javascript'/>\n"
   "  <link rel='shortcut icon' href='/WebCfgD/ico' type='image' />\n"
   "  <title>###OpenSCADA. Dynamic WEB configurator###</title>\n"
   "\n"
   "  <style type='text/css'>\n"
   "    body { background-color:#818181; }\n"
   "    select { font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    #popupmenu { position: absolute; border: 0; width: 150px; height: 150px; overflow : auto; z-index: 10; }\n"
   "    #popupmenu select { background-color: #E6E6E6; border: 1px solid black; padding: 1px; }\n"
   "    #combomenu { position: absolute; border: 1px solid black; width: 100%; height: 120px; overflow: auto; background-color: white; padding: 1px; z-index: 10; }\n"
   "    #combomenu select { background-color: white; border: 0; width: 100%; }\n"
   "    table.main { width: 98%; background-color: #E6E6E6; border: 3px ridge #FF9253; padding: 5px; table-layout: fixed; font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    table.main input,select { font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    table.main td.title { color : blue; font-family : Arial; font-size : 30px; font-style : italic; text-align : center; }\n"
   "    table.main td.tool { text-align: left; border-top: 2px solid black; }\n"
   "    table.main td.tool img { height: 22px; border: 0; vertical-align: middle; }\n"
   "    table.main #status { text-align: left; }\n"
   "    table.main #st_user { width: 50px; white-space: nowrap; text-align: right; }\n"
   "    table.main tr.body { background-color : lightgrey; overflow : auto; }\n"
   "    table.main td.tree { background-color : #F7FFF6; text-align: left; vertical-align : top; border: 3px ridge #F7FFF6; white-space: nowrap; color: black; }\n"
   "    table.main td.tree li.select { background-color : #BDEBED; }\n"
   "    table.main td.tree ul { background-color: #F7FFF6; background-repeat: repeat-y; background-attachment: scroll; background-position: left top; }\n"
   "    table.main td.tree div { overflow: auto; width: 97%; padding: 5px; max-height: 500px; }\n"
   "    table.main td.page { text-align: left; vertical-align : top; border: 3px outset #F7F7F1; background-color: #F7F7F1; }\n"
   "    table.page { width: 100%; padding: 2px; }\n"
   "    table.page td.title { color: black; font-family : Arial; font-size : 20px; font-style : italic; text-align : left; padding-bottom: 5px; }\n"
   "    table.page td.title img { vertical-align: middle; height: 32px; }\n"
   "    table.page td.tabs { }\n"
   "    table.page td.tabs span { padding-left: 5px; padding-right: 5px; padding-bottom: 2px; padding-top: 2px; border: 1px solid gray; white-space: nowrap; background-color: #DEDED9; cursor: pointer; }\n"
   "    table.page td.tabs span.active { background-color: #F7F7F1; cursor: default; border-bottom: 0px none; border-top: 2px solid green; }\n"
   "    table.page td.content { border : 2px ridge grey; text-align : left; vertical-align : top; height: 300px; padding: 5px; }\n"
   "    table.page td.content #pgCont { overflow: auto; width: 100%; max-height: 440px; }\n"
   "    table.page td.content div.elem { margin-bottom: 2px; overflow: visible; width: auto; }\n"
   "    table.page td.content div.elem span.label { white-space: nowrap; padding-right: 3px; }\n"
   "    table.page td.content div.elem span.const { font-weight: bold; }\n"
   "    table.page td.content div.elem textarea { width: 99%; }\n"
   "    table.page td.content fieldset.elem { margin : 0px; margin-bottom: 2px; padding: 3px; }\n"
   "    table.page td.content div.table { width: 600px; border: 1px solid black; height: 200px; background-color: white; overflow: auto; padding: 2px; }\n"
   "    table.page td.content table.elem { border: 1px solid black; border-collapse: collapse; empty-cells: show; }\n"
   "    table.page td.content table.elem th { border: 1px solid black; background-color: #E6E6E6; text-align: center; white-space: nowrap; }\n"
   "    table.page td.content table.elem td { border: 1px solid black; white-space: nowrap; }\n"
   "    table.page td.content table.elem td.hd { background-color: #E6E6E6; font-weight: bold; text-align: center; }\n"
   "    table.page td.content table.elem td input,select { vertical-align: middle; border: 1px solid gray; }\n"
   "    table.page td.content table.elem td img { vertical-align: middle; height: 16px; cursor: pointer; }\n"
   "    table.page td.content table.elem tr.select td { background-color: #00C8FF; }\n"
   "    table.page td.content .list { width: 50%; }\n"
   "    table.page td.content .picture { border: 1px solid blue; vertical-align: top; }\n"
   "    table.page td.content div.elem .line input[size=\"30\"] { width: 50%; }\n"
   "    table.page td.content div.elem .line { padding-right: 3px; }\n"
   "    table.page td.content div.elem .line input,select { vertical-align: middle; border: 1px solid black; }\n"
   "    table.page td.content div.elem .line img { vertical-align: middle; height: 18px; cursor: pointer; }\n"
   "    table.page td.content div.elem .number input { width: 20%; text-align: right; }\n"
   "    ul.tree { clear: both; list-style-image: none; list-style-position: outside; list-style-type: none; margin: 0px; padding: 0px; white-space: nowrap; }\n"
   "    ul.tree a { text-decoration:none; color: black; }\n"
   "    ul.tree a.pm { cursor: pointer; }\n"
   "    ul.tree img { vertical-align:middle; }\n"
   "    ul.tree ul { list-style-image: none; list-style-position: outside; list-style-type: none; margin: 0; padding: 0 0 0 17px; }\n"
   "    a.active img {  cursor: pointer; }\n"
   "    a.inactive img { cursor: default; }\n"
   "    table.dlg { width: 98%; border: 3px ridge #FF9253; background-color: #E6E6E6; padding: 5px; text-align: left; vertical-align: top; font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "    table.dlg select, table.dlg input { font-family: Verdana,Arial,Helvetica,sans-serif; font-size:12px; }\n"
   "  </style>\n"
   "</head>\n"
   "<body alink='#33ccff' link='#3366ff' text='#000000' vlink='#339999'>\n"
   "<table class='main' border='0' cellspacing='3px' align=\"center\">\n"
   "  <tr><td width='30%'></td><td></td></tr>\n"
   "  <tr><td class='title' colspan='2'>###OpenSCADA. Dynamic WEB configurator###</td></tr>\n"
   "  <tr><td class='tool' colspan='2'>\n"
   "  <a id='actLoad' class='inactive' title='###Load###'><img src='/WebCfgD/img_load?filtr=unact&size=22' /></a>\n"
   "  <a id='actSave' class='inactive' title='###Save###'><img src='/WebCfgD/img_save?filtr=unact&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <a id='actUp' class='inactive' title='###Up###'><img src='/WebCfgD/img_up?filtr=unact&size=22' /></a>\n"
   "  <a id='actPrevious' class='inactive' title='###Previous###'><img src='/WebCfgD/img_previous?filtr=unact&size=22' /></a>\n"
   "  <a id='actNext' class='inactive' title='###Next###'><img src='/WebCfgD/img_next?filtr=unact&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line'/>\n"
   "  <a id='actAddIt' class='inactive' title='###Add item###'><img src='/WebCfgD/img_it_add?filtr=unact&size=22' /></a>\n"
   "  <a id='actDelIt' class='inactive' title='###Delete item###'><img src='/WebCfgD/img_it_del?filtr=unact&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line'/>\n"
   "  <a id='actCopy' class='inactive' title='###Copy item###'><img src='/WebCfgD/img_editcopy?filtr=unact&size=22' /></a>\n"
   "  <a id='actCut' class='inactive' title='###Cut item###'><img src='/WebCfgD/img_editcut?filtr=unact&size=22' /></a>\n"
   "  <a id='actPaste' class='inactive' title='###Paste item###'><img src='/WebCfgD/img_editpaste?filtr=unact&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <a id='actUpdate' class='active' title='###Reload item and tree###'><img src='/WebCfgD/img_reload?filtr=none&size=22' /></a>\n"
   "  <a id='actStart' class='active' title='###Start periodic update###'><img src='/WebCfgD/img_start?filtr=none&size=22' /></a>\n"
   "  <a id='actStop' class='inactive' title='###Stop periodic update###'><img src='/WebCfgD/img_stop?filtr=unact&size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <a id='actAbout' class='active' href='/WebCfgD/about' title='###About###'><img src='/WebCfgD/img_help?size=22' /></a>\n"
   "  <img src='/WebCfgD/img_line' />\n"
   "  <span id='selPath' />\n"
   " </td></tr>\n"
   " <tr class='body'>\n"
   "  <td class='tree'><div><ul id='treeRoot' class='tree' /></div></td>\n"
   "  <td class='page'>\n"
   "   <table class='page' border='0' cellspacing='0'>\n"
   "    <tr><td class='title'><img id='pgIco' alt='' /><span id='pgTitle' /></td></tr>\n"
   "    <tr><td id='pgTabs' class='tabs'></td></tr>\n"
   "    <tr><td class='content'><div id='pgCont'></div></td></tr>\n"
   "   </table>\n"
   "  </td>\n"
   " </tr>\n"
   " <tr><td colspan='2'>\n"
   "  <table width='100%'><tr><td id='status'/><td id='st_user'>| <a href=\"/login/WebCfgD/\">##USER##</a></td></tr></table>\n"
   " </td></tr>\n"
   "</table>\n"
   "<script src='/WebCfgD/script.js' type='text/javascript'></script>\n"
   "</body>\n";
